==> haskell-ranged-sets-0.3.0-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ranged-sets.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Ranged-sets
version: 0.3.0
id: Ranged-sets-0.3.0-KhjMIa4fKdwHVkn6xGoafo
key: Ranged-sets-0.3.0-KhjMIa4fKdwHVkn6xGoafo
license: BSD3
copyright: Paul Johnson, 2005, 2006, 2007, 2008
maintainer: paul@cogito.org.uk
stability: beta
homepage: http://code.haskell.org/ranged-sets
synopsis: Ranged sets for Haskell
description:
    A ranged set is an ordered list of ranges.  This allows sets such as all reals x such that:
    .
    > (0.25 < x <= 0.75 or 1.4 <= x < 2.3 or 4.5 < x)
    .
    Alternatively you can have all strings s such that:
    .
    >    ("F" <= s < "G")
category: Data
author: Paul Johnson
exposed: True
indefinite: False
exposed-modules:
    Data.Ranged Data.Ranged.Boundaries Data.Ranged.RangedSet
    Data.Ranged.Ranges
abi: 3c19b2acee7c83c9acffac2796d67f7b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/Ranged-sets-0.3.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/Ranged-sets-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/Ranged-sets-0.3.0
hs-libraries: HSRanged-sets-0.3.0-KhjMIa4fKdwHVkn6xGoafo
depends:
    HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4
    QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l base-4.10.1.0
abi-depends: HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4=cc02d4bbc4678b779cddf8743bb71eea
             QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l=a871331a7e5e7b5c37818b7997512ddd
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-ranged-sets/html/Ranged-sets.haddock
haddock-html: /usr/share/doc/haskell-ranged-sets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ranged-sets-0.3.0-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ranged-sets.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Ranged-sets
version: 0.3.0
id: Ranged-sets-0.3.0-2XvyDmVjy3cCbCoy6mtn6Q
key: Ranged-sets-0.3.0-2XvyDmVjy3cCbCoy6mtn6Q
license: BSD3
copyright: Paul Johnson, 2005, 2006, 2007, 2008
maintainer: paul@cogito.org.uk
stability: beta
homepage: http://code.haskell.org/ranged-sets
synopsis: Ranged sets for Haskell
description:
    A ranged set is an ordered list of ranges.  This allows sets such as all reals x such that:
    .
    > (0.25 < x <= 0.75 or 1.4 <= x < 2.3 or 4.5 < x)
    .
    Alternatively you can have all strings s such that:
    .
    >    ("F" <= s < "G")
category: Data
author: Paul Johnson
exposed: True
indefinite: False
exposed-modules:
    Data.Ranged Data.Ranged.Boundaries Data.Ranged.RangedSet
    Data.Ranged.Ranges
abi: a9dc27ecf3edd04f18aa09ce93a6d866
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/Ranged-sets-0.3.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/Ranged-sets-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/Ranged-sets-0.3.0
hs-libraries: HSRanged-sets-0.3.0-2XvyDmVjy3cCbCoy6mtn6Q
depends:
    HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9 base-4.10.1.0
abi-depends: HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4=cc02d4bbc4678b779cddf8743bb71eea
             QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-ranged-sets/html/Ranged-sets.haddock
haddock-html: /usr/share/doc/haskell-ranged-sets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
